==> haskell-random-fu-0.2.7.7-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-fu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-fu
version:              0.2.7.7
visibility:           public
id:                   random-fu-0.2.7.7-LehisMEibz19jjEU9HvuCz
key:                  random-fu-0.2.7.7-LehisMEibz19jjEU9HvuCz
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random number generation
description:
    Random number generation based on modeling random
    variables in two complementary ways: first, by the
    parameters of standard mathematical distributions and,
    second, by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  e3ec8747c03e58784550f65c7277fa7c
exposed:              True
exposed-modules:
    Data.Random Data.Random.Distribution
    Data.Random.Distribution.Bernoulli Data.Random.Distribution.Beta
    Data.Random.Distribution.Binomial
    Data.Random.Distribution.Categorical
    Data.Random.Distribution.ChiSquare
    Data.Random.Distribution.Dirichlet
    Data.Random.Distribution.Exponential Data.Random.Distribution.Gamma
    Data.Random.Distribution.Multinomial
    Data.Random.Distribution.Normal Data.Random.Distribution.Pareto
    Data.Random.Distribution.Poisson Data.Random.Distribution.Rayleigh
    Data.Random.Distribution.Simplex
    Data.Random.Distribution.StretchedExponential
    Data.Random.Distribution.T Data.Random.Distribution.Triangular
    Data.Random.Distribution.Uniform Data.Random.Distribution.Weibull
    Data.Random.Distribution.Ziggurat Data.Random.Internal.Find
    Data.Random.Internal.Fixed Data.Random.Internal.TH Data.Random.Lift
    Data.Random.List Data.Random.RVar Data.Random.Sample
    Data.Random.Vector

import-dirs:          /usr/lib/ghc-8.10.3/site-local/random-fu-0.2.7.7
library-dirs:         /usr/lib/ghc-8.10.3/site-local/random-fu-0.2.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/random-fu-0.2.7.7
hs-libraries:         HSrandom-fu-0.2.7.7-LehisMEibz19jjEU9HvuCz
depends:
    base-4.14.1.0 erf-2.0.0.0-6AnMvFnwVaM5ZNfg6TTNq1
    math-functions-0.3.4.1-J1bY704KRBN5fyMo1egQRq
    monad-loops-0.4.3-C0LVokhtCoUF1FVS5cJB0Q mtl-2.2.2
    random-1.2.0-30OhcoBMr9kCHjpVnmjVCw
    random-shuffle-0.0.4-7rWuobUibDa5F5zBSheM52
    random-source-0.3.0.11-2MMtYixav646UdfY08UH0s
    rvar-0.2.0.6-Dn5G7PWyICR1ETDlnrH4OE
    syb-0.7.2.1-7YteKEvijmt5wSroPLHLQq template-haskell-2.16.0.0
    transformers-0.5.6.2 vector-0.12.2.0-CTKdHZ2Betb5QHFFflD8i8

haddock-interfaces:   /usr/share/doc/haskell-random-fu/html/random-fu.haddock
haddock-html:         /usr/share/doc/haskell-random-fu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-fu-0.2.7.7-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-fu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-fu
version:              0.2.7.7
visibility:           public
id:                   random-fu-0.2.7.7-CNURg5DcaP6F3WI5cssJMm
key:                  random-fu-0.2.7.7-CNURg5DcaP6F3WI5cssJMm
license:              LicenseRef-PublicDomain
maintainer:           Dominic Steinitz <dominic@steinitz.org>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Random number generation
description:
    Random number generation based on modeling random
    variables in two complementary ways: first, by the
    parameters of standard mathematical distributions and,
    second, by an abstract type ('\''RVar'\'') which can be
    composed and manipulated monadically and sampled in
    either monadic or \"pure\" styles.

    The primary purpose of this library is to support
    defining and sampling a wide variety of high quality
    random variables.  Quality is prioritized over speed,
    but performance is an important goal too.

    In my testing, I have found it capable of speed
    comparable to other Haskell libraries, but still
    a fair bit slower than straight C implementations of
    the same algorithms.

category:             Math
abi:                  01ea91cb9d0ddb8e4726add9cde06e69
exposed:              True
exposed-modules:
    Data.Random Data.Random.Distribution
    Data.Random.Distribution.Bernoulli Data.Random.Distribution.Beta
    Data.Random.Distribution.Binomial
    Data.Random.Distribution.Categorical
    Data.Random.Distribution.ChiSquare
    Data.Random.Distribution.Dirichlet
    Data.Random.Distribution.Exponential Data.Random.Distribution.Gamma
    Data.Random.Distribution.Multinomial
    Data.Random.Distribution.Normal Data.Random.Distribution.Pareto
    Data.Random.Distribution.Poisson Data.Random.Distribution.Rayleigh
    Data.Random.Distribution.Simplex
    Data.Random.Distribution.StretchedExponential
    Data.Random.Distribution.T Data.Random.Distribution.Triangular
    Data.Random.Distribution.Uniform Data.Random.Distribution.Weibull
    Data.Random.Distribution.Ziggurat Data.Random.Internal.Find
    Data.Random.Internal.Fixed Data.Random.Internal.TH Data.Random.Lift
    Data.Random.List Data.Random.RVar Data.Random.Sample
    Data.Random.Vector

import-dirs:          /usr/lib/ghc-8.10.4/site-local/random-fu-0.2.7.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/random-fu-0.2.7.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/random-fu-0.2.7.7
hs-libraries:         HSrandom-fu-0.2.7.7-CNURg5DcaP6F3WI5cssJMm
depends:
    base-4.14.1.0 erf-2.0.0.0-6AnMvFnwVaM5ZNfg6TTNq1
    math-functions-0.3.4.1-7iiQVe6wd7hJmeDUFqe1Ej
    monad-loops-0.4.3-C0LVokhtCoUF1FVS5cJB0Q mtl-2.2.2
    random-1.2.0-JTLC2c0pp0nLNcssukvhHY
    random-shuffle-0.0.4-6CijbUp5A2H4JKKAcWtS1T
    random-source-0.3.0.11-8VsjNOmuxw18QHfzvJo6JP
    rvar-0.2.0.6-IzIw0ZKCSB8EIwqBkWvZrt
    syb-0.7.2.1-3NRuID5KtwUDKtTIjLYVTX template-haskell-2.16.0.0
    transformers-0.5.6.2 vector-0.12.2.0-Ah3gN1EocbtK6SkxatFMVl

haddock-interfaces:   /usr/share/doc/haskell-random-fu/html/random-fu.haddock
haddock-html:         /usr/share/doc/haskell-random-fu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
